def main():
    import os
    path = input("enter full directory path: ")
    files = os.listdir(path)
    mainDirectorylist = list()

    for i in files:
        if i.startswith(".") == False:
            mainDirectorylist.append(i)
            filename = i.lower()
            if " " in filename:
                filename = filename.replace(" ", "_")
            if "-" in filename:
                filename = filename.replace("-", "_")
            confirmation = input(
                f"\n{mainDirectorylist[files.index(i)]} => {filename} (Y/n): ")
            if confirmation.lower() == "y" or "":
                os.rename(
                    f"{path}/{mainDirectorylist[files.index(i)]}", f"{path}/{filename}")
            else:
                continue

    print("\nAight, I'm done!")



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="rename-dirs",
    version="1.2.0",
    author="Rachit Gupta",
    author_email="guptarachit2004@gmail.com",
    description="A python script to rename multiple directories to lowercase words with underscore separators.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/rchtgpt/rename-dirs",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    entry_points={'console_scripts': [
        'rename-dirs=rename_dirs.__main__:main']},
)
